@@ -1,20 +1,23 @@
 package Catmandu::RDF;
 # ABSTRACT: Modules for handling RDF data within the Catmandu framework
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Catmandu::RDF - Modules for handling RDF data within the Catmandu framework
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
@@ -29,6 +32,8 @@ contributions are very welcome at L<https://github.com/nichtich/Catmandu-RDF>!
 =item L<Catmandu::Exporter::RDF>
 
 Serialize RDF data (as RDF/XML, RDF/JSON, Turtle, NTriples, RDFa...).
+RDF data must be provided in B<another RDF Encoding Form (aREF)> as 
+implemented with L<RDF::aREF>.
 
 =back
 
@@ -57,11 +62,9 @@ Export RDF with HTTP PATCH.
 
 =back
 
-=encoding utf8
-
 =head1 SEE ALSO
 
-L<Catmandu>, L<RDF::Trine>, L<RDF::NS>
+L<Catmandu>, L<RDF::aREF>, L<RDF::Trine>, L<RDF::NS>
 
 =head1 AUTHOR
 
@@ -75,4 +78,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
